@@ -229,15 +229,28 @@ def linearized_derivatives(
     if not ode.is_finalized:
         error("The ODE is not finalized")
 
-    return LinearizedDerivativeComponent(
-        ode,
-        function_name,
-        result_names,
-        only_linear,
-        include_rhs,
-        nonlinear_last,
-        params,
-    )
+    # This component is a bit flaky, but it usually works
+    # if we retry
+    for retry in range(5):
+        try:
+            comp = LinearizedDerivativeComponent(
+                ode,
+                function_name,
+                result_names,
+                only_linear,
+                include_rhs,
+                nonlinear_last,
+                params,
+            )
+        except KeyError:
+            continue
+        else:
+            break
+
+    else:
+        raise KeyError("Unable to create LinearizedDerivativeComponent")
+
+    return comp
 
 
 def jacobian_expressions(
@@ -483,7 +496,6 @@ class JacobianComponent(CodeComponent):
             sys.stdout.flush()
 
         for i, expr in enumerate(state_exprs):
-
             states_syms = sorted(
                 (state_dict[sym], sym)
                 for sym in ode_primitives(expr.expr, time_sym)
@@ -788,9 +800,7 @@ class FactorizedJacobianComponent(CodeComponent):
 
         # Do the factorization
         for j in range(n):
-
             for i in range(j):
-
                 # Get sympy expr of A_ij
                 jac_ij = jac[i, j]
 
@@ -803,7 +813,6 @@ class FactorizedJacobianComponent(CodeComponent):
             pivot = -1
 
             for i in range(j, n):
-
                 # Get sympy expr of A_ij
                 jac_ij = jac[i, j]
 
@@ -835,7 +844,6 @@ class FactorizedJacobianComponent(CodeComponent):
 
             scale = 1 / jac[j, j]
             for i in range(j + 1, n):
-
                 # Get sympy expr of A_ij
                 jac_ij = jac[i, j]
                 jac_ij *= scale
@@ -935,7 +943,6 @@ class ForwardBackwardSubstitutionComponent(CodeComponent):
         dx = []
         # forward substitution, all diag entries are scaled to 1
         for i in range(n):
-
             F.append(self.add_indexed_object(residual_name, i))
             dx.append(self.add_indexed_expression(result_name, i, F[i]))
 
@@ -1034,7 +1041,6 @@ class LinearizedDerivativeComponent(CodeComponent):
 
         nonlinear_exprs = []
         for ind, expr in enumerate(state_exprs):
-
             expr_diff = expr.expr.diff(expr.state.sym)
 
             if expr_diff and expr.state.sym not in expr_diff.args:
@@ -1115,7 +1121,6 @@ class CommonSubExpressionODE(ODE):
 
         # Register the common sub expressions as Intermediates
         for sub, expr in cse_exprs:
-
             # If the expression is just one of the atoms of the ODE we skip
             # the cse expressions but add a subs for the atom
             if expr in atoms:
@@ -1129,7 +1134,6 @@ class CommonSubExpressionODE(ODE):
 
         # Register the state expressions
         for org_state_expr, state_expr in zip(org_state_expressions, cse_state_exprs):
-
             exp_expr = state_expr.xreplace(cse_subs)
             state = self.get_object(org_state_expr.state.name)[1]
 
